==> vdr-plugin-webvideo_0.2.1.orig.tar.gz: webvideo-0.2.1/src/vdr-plugin/menu.h <==
/*
 * menu.h: Web video plugin for the Video Disk Recorder
 *
 * See the README file for copyright information and how to reach the author.
 *
 * $Id$
 */

#ifndef __WEBVIDEO_MENU_H
#define __WEBVIDEO_MENU_H

#include <time.h>
#include <vdr/osdbase.h>
#include <vdr/menuitems.h>
#include <vdr/menu.h>
#include <libxml/parser.h>
#include "download.h"

// --- cLinkBase -----------------------------------------------------------

class cLinkBase {
public:
  virtual ~cLinkBase() {}; // avoids "virtual functions but
			   // non-virtual destructor" warning

  virtual char *GetURL() = 0;
};

// --- cQueryData ----------------------------------------------------------

class cQueryData {
public:
  virtual ~cQueryData() {}; // avoids "virtual functions but
			    // non-virtual destructor" warning

  virtual char *GetQueryFragment() = 0;
};

// --- cSimpleLink ---------------------------------------------------------

class cSimpleLink : public cLinkBase {
private:
  char *ref;
public:
  cSimpleLink(const char *ref);
  ~cSimpleLink();

  virtual char *GetURL();
};

// --- cTextFieldData ------------------------------------------------------

class cTextFieldData : public cQueryData {
private:
  char *name;
  char *valuebuffer;
  int valuebufferlength;
public:
  cTextFieldData(int Length, const char *Name);
  ~cTextFieldData();

  virtual char *GetQueryFragment();
  char *GetValue();
  int GetLength();
};

// --- cItemListData -------------------------------------------------------

class cItemListData : public cQueryData {
private:
  char *name;
  int value;
  int numstrings;
  char **strings;
  char **stringvalues;
public:
  cItemListData(char **Strings, char **StringValues, int NumStrings, const char *Name);
  ~cItemListData();

  virtual char *GetQueryFragment();
  char **GetStrings();
  char **GetStringValues();
  int GetNumStrings();
  int *GetValuePtr();
};

// --- cSubmissionButtonData -----------------------------------------------

class cSubmissionButtonData : public cLinkBase {
private:
  cVector<cQueryData *> *queryObjects;
  char *querybase;
public:
  cSubmissionButtonData(const char *queryUrl, cVector<cQueryData *> *objects);
  ~cSubmissionButtonData();

  virtual char *GetURL();
};

// --- cXMLMenu --------------------------------------------------

class cXMLMenu : public cOsdMenu {
protected:
  virtual void Deserialize(xmlDocPtr doc, xmlNodePtr root);
  virtual bool CreateItemFromTag(xmlDocPtr doc, xmlNodePtr node) = 0;
public:
  cXMLMenu(const char *Title, int c0 = 0, int c1 = 0, 
           int c2 = 0, int c3 = 0, int c4 = 0);

  int Load(const char *xmlstr);
};

// --- cNavigationMenu -----------------------------------------------------

enum eLinkType { LT_REGULAR, LT_MEDIA, LT_STREAMINGMEDIA };

class cHistory;
class cHistoryObject;
class cStatusScreen;

class cNavigationMenu : public cXMLMenu {
private:
  // links[i] is the navigation link of the i:th item
  cVector<cLinkBase *> links;
  // streams[i] is the media stream link of the i:th item
  cVector<cLinkBase *> streams;
  // queryObjects contains items that should be included in the menu's query
  cVector<cQueryData *> queryObjects;
  cNavigationMenu **pluginMenuPointer;
  cStatusScreen *statusscreen;
protected:
  cHistory *history;
  cWebviThread *downloadthread;

  virtual bool CreateItemFromTag(xmlDocPtr doc, xmlNodePtr node);
  void AddLinkItem(cOsdItem *item, cLinkBase *ref, 
                   cLinkBase *streamref, cQueryData *queryobject);
  void NewLinkItem(xmlDocPtr doc, xmlNodePtr node);
  void NewTextField(xmlDocPtr doc, xmlNodePtr node);
  void NewItemList(xmlDocPtr doc, xmlNodePtr node);
  void NewTextArea(xmlDocPtr doc, xmlNodePtr node);
  void NewButton(xmlDocPtr doc, xmlNodePtr node);
  void NewTitle(xmlDocPtr doc, xmlNodePtr node);
public:
  cNavigationMenu(cNavigationMenu **parentMenuPointer, cHistory *History, 
                  cWebviThread *dlthread);
  virtual ~cNavigationMenu();

  virtual eOSState ProcessKey(eKeys Key);
  virtual eOSState Select(cLinkBase *link, eLinkType type);
  virtual void Clear(void);
  eOSState HistoryBack();
  eOSState HistoryForward();

  void Populate(cHistoryObject *page, const char *statusmsg=NULL);
  void UpdateHelp();

  void SetStatusScreen(cStatusScreen* status) { statusscreen = status; };
  cStatusScreen *GetStatusScreen();
};

// --- cStatusScreen -------------------------------------------------------

class cStatusScreen : public cOsdMenu {
public:
  const static time_t updateInterval = 5;
private:
  cWebviThread *downloadthread;
  cVector<cDownloadProgress *> summaries;
  cNavigationMenu* parentmenu;
  time_t lastupdate;
public:
  cStatusScreen(cNavigationMenu* parent, cWebviThread *thread);
  ~cStatusScreen();

  void Update();
  bool NeedsUpdate();

  virtual eOSState ProcessKey(eKeys Key);
};

#endif // __WEBVIDEO_MENU_H

==> vdr-plugin-webvideo_0.2.2.orig.tar.gz: webvideo-0.2.2/src/vdr-plugin/menu.h <==
/*
 * menu.h: Web video plugin for the Video Disk Recorder
 *
 * See the README file for copyright information and how to reach the author.
 *
 * $Id$
 */

#ifndef __WEBVIDEO_MENU_H
#define __WEBVIDEO_MENU_H

#include <time.h>
#include <vdr/osdbase.h>
#include <vdr/menuitems.h>
#include <vdr/menu.h>
#include <libxml/parser.h>
#include "download.h"
#include "menudata.h"

extern cCharSetConv csc;

// --- cXMLMenu --------------------------------------------------

class cXMLMenu : public cOsdMenu {
protected:
  virtual bool Deserialize(const char *xml);
  virtual bool CreateItemFromTag(xmlDocPtr doc, xmlNodePtr node) = 0;
public:
  cXMLMenu(const char *Title, int c0 = 0, int c1 = 0, 
           int c2 = 0, int c3 = 0, int c4 = 0);

  int Load(const char *xmlstr);
};

// --- cNavigationMenu -----------------------------------------------------

enum eLinkType { LT_REGULAR, LT_MEDIA, LT_STREAMINGMEDIA };

class cHistory;
class cHistoryObject;
class cStatusScreen;

class cNavigationMenu : public cXMLMenu {
private:
  // links[i] is the navigation link of the i:th item
  cVector<cLinkBase *> links;
  // streams[i] is the media stream link of the i:th item
  cVector<cLinkBase *> streams;
  cNavigationMenu **pluginMenuPointer;
  cStatusScreen *statusscreen;

protected:
  cHistory *history;
  cWebviThread *downloadthread;

  virtual bool CreateItemFromTag(xmlDocPtr doc, xmlNodePtr node);
  void AddLinkItem(cOsdItem *item, cLinkBase *ref, cLinkBase *streamref);
  void NewLinkItem(xmlDocPtr doc, xmlNodePtr node);
  void NewTextField(xmlDocPtr doc, xmlNodePtr node);
  void NewItemList(xmlDocPtr doc, xmlNodePtr node);
  void NewTextArea(xmlDocPtr doc, xmlNodePtr node);
  void NewButton(xmlDocPtr doc, xmlNodePtr node);
  void NewTitle(xmlDocPtr doc, xmlNodePtr node);

public:
  cNavigationMenu(cNavigationMenu **parentMenuPointer, cHistory *History, 
                  cWebviThread *dlthread);
  virtual ~cNavigationMenu();

  virtual eOSState ProcessKey(eKeys Key);
  virtual eOSState Select(cLinkBase *link, eLinkType type);
  virtual void Clear(void);
  eOSState HistoryBack();
  eOSState HistoryForward();

  void Populate(cHistoryObject *page, const char *statusmsg=NULL);
  void UpdateHelp();

  void SetStatusScreen(cStatusScreen* status) { statusscreen = status; };
  cStatusScreen *GetStatusScreen();
};

// --- cStatusScreen -------------------------------------------------------

class cStatusScreen : public cOsdMenu {
public:
  const static time_t updateInterval = 5;
private:
  cWebviThread *downloadthread;
  cVector<cDownloadProgress *> summaries;
  cNavigationMenu* parentmenu;
  time_t lastupdate;
public:
  cStatusScreen(cNavigationMenu* parent, cWebviThread *thread);
  ~cStatusScreen();

  void Update();
  bool NeedsUpdate();

  virtual eOSState ProcessKey(eKeys Key);
};

#endif // __WEBVIDEO_MENU_H
